==> side_menu_v1.26.0.tar.gz: side_menu/l10n/cs.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Uživatelsky určená nabídka",
    "Enable the custom menu": "Zapnout uživatelsky určenou nabídku",
    "No": "Ne",
    "Yes": "Ano",
    "Menu": "Nabídka",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Pro otevření\/skrytí postranní nabídky použijte zkratku <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span>. Pro pohyb po použijte klávesu <span class=\"keyboard-key\">tab<\/span>.",
    "Top menu": "Hlavní nabídka",
    "Apps that not must be moved in the side menu": "Aplikace, které nepřesouvat do postranní nabídky",
    "If there is no selection then the global configuration is applied.": "Pokud neexistuje žádný výběr, je uplatněno globální nastavení.",
    "Experimental": "Experimentální",
    "Save": "Uložit",
    "You like this app and you want to support me?": "Líbí se vám tato aplikace a chcete podpořit její vývoj?",
    "Buy me a coffee ☕": "Kupte mi kafe ☕",
    "Hidden": "Skryté",
    "Small": "Malé",
    "Normal": "Normální",
    "Big": "Velké",
    "Colors": "Barvy",
    "Background color": "Barva pozadí",
    "Background color of current app": "Barva pozadí stávající aplikace",
    "Text color": "Barva textu",
    "Loader": "Nástroj pro načítání",
    "Icon": "Ikona",
    "Same color": "Stejná barva",
    "Opposite color": "Doplňková barva",
    "Transparent": "Průhledné",
    "Opaque": "Neprůhledné",
    "Opener": "Tlačítko pro otevření",
    "Default": "Výchozí",
    "Default (dark)": "Výchozí (tmavé)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (tmavé)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (tmavé)",
    "Before the logo": "Před logem",
    "After the logo": "Za logem",
    "Position": "Pozice",
    "Show only the opener (hidden logo)": "Zobrazovat pouze otevírací tlačítko (logo skryto)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Nezobrazovat postranní nabídku a její otevírací tlačítko pokud nejsou dostupné žádné aplikace (např. na veřejných stránkách).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Otevřít nabídku při najetím ukazatelem na tlačítko nabídky (automaticky vypnuto pro dotykové obrazovky).",
    "Display the big menu": "Zobrazit velkou nabídku",
    "The big menu is not compatible with AppOrder.": "Velká nabídka není kompatibilní s jinou aplikací (doplňkem) „Pořadí aplikací“.",
    "Display the logo": "Zobrazit logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Tato funkce není kompatibilní se zobrazením <code>velké nabídky<\/code>.",
    "Icons and texts": "Ikony a texty",
    "Loader enabled": "Načítání zapnuto",
    "Tips": "Tipy",
    "Always displayed": "Vždy zobrazeno",
    "The logo will be hidden when the menu is always displayed.": "Pokud je nabídka zobrazena trvale, logo bude skryto.",
    "This is the automatic behavior when the menu is always displayed.": "Toto je automatické chování, kdy je nabídka vždy zobrazena.",
    "Not compatible with touch screens.": "Nekompatibilní s dotykovými obrazovkami.",
    "Big menu": "Velká nabídka",
    "Live preview": "Živý náhled",
    "Open apps in new tab": "Otevírat aplikace v novém panelu",
    "Use the global setting": "Použít globální nastavení",
    "Use my selection": "Použít můj výběr",
    "Show and hide the list of applications": "Zobrazit\/skrýt seznam aplikací",
    "Use the avatar instead of the logo": "Použít namísto loga profilový obrázek uživatele",
    "You do not have permission to change the settings.": "Nemáte oprávnění měnit nastavení.",
    "Force this configuration to users": "Vynutit uplatnění těchto nastavení uživatelům",
    "Export the configuration": "Exportovat nastavení",
    "Purge the cache": "Vyprázdnit mezipaměť",
    "Show the link to settings": "Zobrazit odkaz na nastavení",
    "The menu is enabled by default for users": "Nabídka je ve výchozím stavu zapnutá pro uživatele",
    "Except when the configuration is forced.": "S výjimkou, kdy je nastavení vynuceno.",
    "Apps that should not be displayed in the menu": "Aplikace, které by neměly být v nabídce zobrazeny",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Tato funkce je kompatibilní pouze s <code>velkou nabídkou<\/ code>.",
    "The logo is a link to the default app": "Logo je odkaz na výchozí aplikaci",
    "Others": "Ostatní",
    "Categories": "Kategorie",
    "Customize sorting": "Přizpůsobit si řazení",
    "Order by": "Řadit podle",
    "Name": "Název",
    "Customed": "Přizpůsobeno",
    "Show and hide the list of categories": "Zobrazit\/skrýt seznam kategorií",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Tyto parametry jsou použity v případě, že je zapnutý (Breeze) tmavý motiv vzhledu.",
    "Dark mode colors": "Barvy tmavého režimu"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v2.0.1.tar.gz: side_menu/l10n/cs.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Uživatelsky určená nabídka",
    "Enable the custom menu": "Zapnout uživatelsky určenou nabídku",
    "No": "Ne",
    "Yes": "Ano",
    "Menu": "Nabídka",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Pro otevření\/skrytí postranní nabídky použijte zkratku <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span>. Pro pohyb po použijte klávesu <span class=\"keyboard-key\">tab<\/span>.",
    "Top menu": "Hlavní nabídka",
    "Apps that not must be moved in the side menu": "Aplikace, které nepřesouvat do postranní nabídky",
    "If there is no selection then the global configuration is applied.": "Pokud neexistuje žádný výběr, je uplatněno globální nastavení.",
    "Experimental": "Experimentální",
    "Save": "Uložit",
    "You like this app and you want to support me?": "Líbí se vám tato aplikace a chcete podpořit její vývoj?",
    "Buy me a coffee ☕": "Kupte mi kafe ☕",
    "Hidden": "Skryté",
    "Small": "Malé",
    "Normal": "Normální",
    "Big": "Velké",
    "Colors": "Barvy",
    "Background color": "Barva pozadí",
    "Background color of current app": "Barva pozadí stávající aplikace",
    "Text color": "Barva textu",
    "Loader": "Nástroj pro načítání",
    "Icon": "Ikona",
    "Same color": "Stejná barva",
    "Opposite color": "Doplňková barva",
    "Transparent": "Průhledné",
    "Opaque": "Neprůhledné",
    "Opener": "Tlačítko pro otevření",
    "Default": "Výchozí",
    "Default (dark)": "Výchozí (tmavé)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (tmavé)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (tmavé)",
    "Before the logo": "Před logem",
    "After the logo": "Za logem",
    "Position": "Pozice",
    "Show only the opener (hidden logo)": "Zobrazovat pouze otevírací tlačítko (logo skryto)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Nezobrazovat postranní nabídku a její otevírací tlačítko pokud nejsou dostupné žádné aplikace (např. na veřejných stránkách).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Otevřít nabídku při najetím ukazatelem na tlačítko nabídky (automaticky vypnuto pro dotykové obrazovky).",
    "Display the big menu": "Zobrazit velkou nabídku",
    "This menu is not compatible with AppOrder.": "Nabídka není kompatibilní s jinou aplikací (doplňkem) „Pořadí aplikací“.",
    "Display the logo": "Zobrazit logo",
    "This feature is not compatible with the <code>big menu<\/code> display.": "Tato funkce není kompatibilní se zobrazením <code>velké nabídky<\/code>.",
    "Icons and texts": "Ikony a texty",
    "Loader enabled": "Načítání zapnuto",
    "Tips": "Tipy",
    "Always displayed": "Vždy zobrazeno",
    "The logo will be hidden when the menu is always displayed.": "Pokud je nabídka zobrazena trvale, logo bude skryto.",
    "This is the automatic behavior when the menu is always displayed.": "Toto je automatické chování, kdy je nabídka vždy zobrazena.",
    "Not compatible with touch screens.": "Nekompatibilní s dotykovými obrazovkami.",
    "Big menu": "Velká nabídka",
    "Live preview": "Živý náhled",
    "Open apps in new tab": "Otevírat aplikace v novém panelu",
    "Use the global setting": "Použít globální nastavení",
    "Use my selection": "Použít můj výběr",
    "Show and hide the list of applications": "Zobrazit\/skrýt seznam aplikací",
    "Use the avatar instead of the logo": "Použít namísto loga profilový obrázek uživatele",
    "You do not have permission to change the settings.": "Nemáte oprávnění měnit nastavení.",
    "Force this configuration to users": "Vynutit uplatnění těchto nastavení uživatelům",
    "Export the configuration": "Exportovat nastavení",
    "Purge the cache": "Vyprázdnit mezipaměť",
    "Show the link to settings": "Zobrazit odkaz na nastavení",
    "The menu is enabled by default for users": "Nabídka je ve výchozím stavu zapnutá pro uživatele",
    "Except when the configuration is forced.": "S výjimkou, kdy je nastavení vynuceno.",
    "Apps that should not be displayed in the menu": "Aplikace, které by neměly být v nabídce zobrazeny",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Tato funkce je kompatibilní pouze s <code>velkou nabídkou<\/ code>.",
    "The logo is a link to the default app": "Logo je odkaz na výchozí aplikaci",
    "Others": "Ostatní",
    "Categories": "Kategorie",
    "Customize sorting": "Přizpůsobit si řazení",
    "Order by": "Řadit podle",
    "Name": "Název",
    "Customed": "Přizpůsobeno",
    "Show and hide the list of categories": "Zobrazit\/skrýt seznam kategorií",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Tyto parametry jsou použity v případě, že je zapnutý (Breeze) tmavý motiv vzhledu.",
    "Dark mode colors": "Barvy tmavého režimu",
    "With categories": "S kategoriemi"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
